Crate redis_ipc

Crate redis_ipc 

Introduction

Simple crate, which wraps redis a few types into Rust structures. These structures are destined to be used in inter-process or service-to-service communication.

Re-exports

pub use cache::Cache;
pub use queue::ReadQueue;
pub use queue::WriteQueue;
pub use stream::ReadStream;
pub use stream::WriteStream;

Modules

cache
error
This module covers everything related to error handling in this crate.
helpers
Module provides some helper functions, which may be useful when building ipc.
queue
stream

Type Aliases

OptionalTimeout
Sometimes timeouts are optional, and None may be used instead of specified timeout. This type alias cover this possibility.
OptionalTtl
Optional ttl, similar to OptionalTimeout
RedisConnection
Alias for connection, which may be got from pool.
RedisPool
Type alias for Pool with Client, which is used widely in this crate.
Timeout
Alias for specifying timeouts in this crate.
Ttl
Type alias for “Time To Live” function parameters in this crate.