Introduction
Simple crate, which wraps redis a few types into Rust structures. These structures are destined to be used in inter-process or service-to-service communication.
Re-exports
pub use cache::Cache;pub use queue::ReadQueue;pub use queue::WriteQueue;pub use stream::ReadStream;pub use stream::WriteStream;
Modules
- cache
- error
- This module covers everything related to error handling in this crate.
- helpers
- Module provides some helper functions, which may be useful when building ipc.
- queue
- stream
Type Aliases
- Optional
Timeout - Sometimes timeouts are optional, and
Nonemay be used instead of specified timeout. This type alias cover this possibility. - Optional
Ttl - Optional ttl, similar to
OptionalTimeout - Redis
Connection - Alias for connection, which may be got from pool.
- Redis
Pool - Type alias for
PoolwithClient, which is used widely in this crate. - Timeout
- Alias for specifying timeouts in this crate.
- Ttl
- Type alias for “Time To Live” function parameters in this crate.